@@ -25,7 +25,7 @@ impl Departments {
      * * `start: &str` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      * * `page_size: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
      */
-    pub async fn get_departments(
+    pub async fn get_page(
         &self,
         start: &str,
         page_size: f64,
@@ -55,13 +55,37 @@ impl Departments {
      *
      * This function performs a `GET` to the `/departments` endpoint.
      *
-     * As opposed to `get_departments`, this function returns all the pages of the request at once.
+     * As opposed to `get`, this function returns all the pages of the request at once.
      *
      * Retrieve all departments.
      */
-    pub async fn get_all_departments(&self) -> Result<Vec<crate::types::Department>> {
+    pub async fn get_all(&self) -> Result<Vec<crate::types::Department>> {
         let url = "/departments".to_string();
-        self.client.get_all_pages(&url, None).await
+        let mut resp: crate::types::GetDepartmentsResponse =
+            self.client.get(&url, None).await.unwrap();
+
+        let mut data = resp.data;
+        let mut page = resp.page.next;
+
+        // Paginate if we should.
+        while !page.is_empty() {
+            resp = self
+                .client
+                .get(page.trim_start_matches(crate::DEFAULT_HOST), None)
+                .await
+                .unwrap();
+
+            data.append(&mut resp.data);
+
+            if !resp.page.next.is_empty() && resp.page.next != page {
+                page = resp.page.next.to_string();
+            } else {
+                page = "".to_string();
+            }
+        }
+
+        // Return our response data.
+        Ok(data)
     }
 
     /**
@@ -87,7 +111,7 @@ impl Departments {
     /**
      * GET a department.
      *
-     * This function performs a `GET` to the `/departments/<id>` endpoint.
+     * This function performs a `GET` to the `/departments/{id}` endpoint.
      *
      * Retrieve a single department.
      *
@@ -95,23 +119,32 @@ impl Departments {
      *
      * * `authorization: &str` -- The OAuth2 token header.
      */
-    pub async fn get_department(&self) -> Result<crate::types::Department> {
-        let url = "/departments/<id>".to_string();
+    pub async fn get_department(&self, id: &str) -> Result<crate::types::Department> {
+        let url = format!(
+            "/departments/{}",
+            crate::progenitor_support::encode_path(&id.to_string()),
+        );
+
         self.client.get(&url, None).await
     }
 
     /**
      * Update department.
      *
-     * This function performs a `PATCH` to the `/departments/<id>` endpoint.
+     * This function performs a `PATCH` to the `/departments/{id}` endpoint.
      *
      * Modify a department.
      */
     pub async fn patch_department(
         &self,
-        body: &crate::types::PatchDepartmentRequest,
+        id: &str,
+        body: &crate::types::PostLocationRequest,
     ) -> Result<crate::types::Department> {
-        let url = "/departments/<id>".to_string();
+        let url = format!(
+            "/departments/{}",
+            crate::progenitor_support::encode_path(&id.to_string()),
+        );
+
         self.client
             .patch(
                 &url,
