@@ -61,7 +61,31 @@ impl Locations {
      */
     pub async fn get_all_locations(&self) -> Result<Vec<crate::types::Location>> {
         let url = "/locations".to_string();
-        self.client.get_all_pages(&url, None).await
+        let mut resp: crate::types::GetLocationResponse =
+            self.client.get(&url, None).await.unwrap();
+
+        let mut data = resp.data;
+        let mut page = resp.page.next;
+
+        // Paginate if we should.
+        while !page.is_empty() {
+            resp = self
+                .client
+                .get(page.trim_start_matches(crate::DEFAULT_HOST), None)
+                .await
+                .unwrap();
+
+            data.append(&mut resp.data);
+
+            if !resp.page.next.is_empty() && resp.page.next != page {
+                page = resp.page.next.to_string();
+            } else {
+                page = "".to_string();
+            }
+        }
+
+        // Return our response data.
+        Ok(data)
     }
 
     /**
@@ -91,7 +115,7 @@ impl Locations {
     /**
      * GET a location.
      *
-     * This function performs a `GET` to the `/locations/<id>` endpoint.
+     * This function performs a `GET` to the `/locations/{id}` endpoint.
      *
      * Retrieve a specific location.
      *
@@ -99,23 +123,32 @@ impl Locations {
      *
      * * `authorization: &str` -- The OAuth2 token header.
      */
-    pub async fn get_location(&self) -> Result<crate::types::Location> {
-        let url = "/locations/<id>".to_string();
+    pub async fn get_location(&self, id: &str) -> Result<crate::types::Location> {
+        let url = format!(
+            "/locations/{}",
+            crate::progenitor_support::encode_path(&id.to_string()),
+        );
+
         self.client.get(&url, None).await
     }
 
     /**
      * Update location.
      *
-     * This function performs a `PATCH` to the `/locations/<id>` endpoint.
+     * This function performs a `PATCH` to the `/locations/{id}` endpoint.
      *
      * Modifies a specific location.
      */
     pub async fn patch_location(
         &self,
-        body: &crate::types::PatchLocationRequest,
+        id: &str,
+        body: &crate::types::PostLocationRequest,
     ) -> Result<crate::types::Location> {
-        let url = "/locations/<id>".to_string();
+        let url = format!(
+            "/locations/{}",
+            crate::progenitor_support::encode_path(&id.to_string()),
+        );
+
         self.client
             .patch(
                 &url,
